@@ -7,7 +7,7 @@
 #include "selinux_internal.h"
 #include "policy.h"
 
-int fsetfilecon_raw(int fd, security_context_t context)
+int fsetfilecon_raw(int fd, const security_context_t context)
 {
 	return fsetxattr(fd, XATTR_NAME_SELINUX, context, strlen(context) + 1,
 			 0);
@@ -15,10 +15,10 @@ int fsetfilecon_raw(int fd, security_context_t context)
 
 hidden_def(fsetfilecon_raw)
 
-int fsetfilecon(int fd, security_context_t context)
+int fsetfilecon(int fd, const security_context_t context)
 {
 	int ret;
-	security_context_t rcontext = context;
+	security_context_t rcontext;
 
 	if (selinux_trans_to_raw_context(context, &rcontext))
 		return -1;
