@@ -3,6 +3,7 @@
 #include "dso.h"
 
 hidden_proto(selinux_mkload_policy)
+    hidden_proto(fini_selinuxmnt)
     hidden_proto(set_selinuxmnt)
     hidden_proto(security_disable)
     hidden_proto(security_policyvers)
@@ -65,6 +66,7 @@ hidden_proto(selinux_mkload_policy)
     hidden_proto(selinux_file_context_path)
     hidden_proto(selinux_file_context_homedir_path)
     hidden_proto(selinux_file_context_local_path)
+    hidden_proto(selinux_file_context_subs_dist_path)
     hidden_proto(selinux_file_context_subs_path)
     hidden_proto(selinux_netfilter_context_path)
     hidden_proto(selinux_homedir_context_path)
@@ -98,6 +100,7 @@ extern int selinux_page_size hidden;
 /* Make pthread_once optional */
 #pragma weak pthread_once
 #pragma weak pthread_key_create
+#pragma weak pthread_key_delete
 #pragma weak pthread_setspecific
 
 /* Call handler iff the first call.  */
@@ -113,9 +116,12 @@ extern int selinux_page_size hidden;
 
 /* Pthread key macros */
 #define __selinux_key_create(KEY, DESTRUCTOR)			\
+	(pthread_key_create != NULL ? pthread_key_create(KEY, DESTRUCTOR) : -1)
+
+#define __selinux_key_delete(KEY)				\
 	do {							\
-		if (pthread_key_create != NULL)			\
-			pthread_key_create(KEY, DESTRUCTOR);	\
+		if (pthread_key_delete != NULL)			\
+			pthread_key_delete(KEY);		\
 	} while (0)
 
 #define __selinux_setspecific(KEY, VALUE)			\
